==> nextcloud-24.0.5.tgz: nextcloud/apps/photos/l10n/is.js <==
OC.L10N.register(
    "photos",
    {
    "Photos" : "Ljósmyndir",
    "Your memories under your control" : "Haltu minningunum þínum undir þinni stjórn",
    "Videos" : "Myndskeið",
    "People" : "Fólk",
    "Folders" : "Möppur",
    "Favorites" : "Eftirlæti",
    "On this day" : "Á þessum degi",
    "Shared with you" : "Deilt með þér",
    "Tags" : "Merki",
    "Locations" : "Staðsetningar",
    "Photos settings" : "Stillingar ljósmynda",
    "Back" : "Til baka",
    "Save" : "Vista",
    "Open the full size \"{name}\" image" : "Opna myndina \"{name}\" í fullri stærð",
    "Open the \"{name}\" sub-directory" : "Opna \"{name}\" undirmöppuna",
    "Back to {folder}" : "Til baka í {folder}",
    "Share this folder" : "Deila þessari möppu",
    "_{years} year ago_::_{years} years ago_" : ["Fyrir {years} ári","Fyrir {years} árum"],
    "Enable squared photos view" : "Virkja sýn með ferköntuðum myndum",
    "View" : "Skoða",
    "An error occurred" : "Villa kom upp",
    "Favorite" : "Eftirlæti",
    "Remove from favorites" : "Fjarlægja úr eftirlætum",
    "This folder does not exist" : "Þessi mappa er ekki til",
    "No photos in here" : "Engar myndir hér",
    "No tags yet" : "Engin merki ennþá",
    "Photos with tags will show up here" : "Ljósmyndir með merkjum munu birtast hér",
    "Add" : "Bæta við",
    "Download" : "Sækja",
    "Delete selection" : "Eyða vali",
    "Delete" : "Eyða",
    "Tagged photos" : "Merktar ljósmyndir",
    "Your photos" : "Ljósmyndirnar þínar",
    "Your videos" : "Myndskeiðin þín",
    "Your folders" : "Möppurnar þínar",
    "Settings" : "Stillingar"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-24.0.8.tgz: nextcloud/apps/photos/l10n/is.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Opinber tengill",
    "Photos" : "Ljósmyndir",
    "Your memories under your control" : "Haltu minningunum þínum undir þinni stjórn",
    "Videos" : "Myndskeið",
    "People" : "Fólk",
    "Folders" : "Möppur",
    "Favorites" : "Eftirlæti",
    "On this day" : "Á þessum degi",
    "Shared with you" : "Deilt með þér",
    "Tags" : "Merki",
    "Locations" : "Staðsetningar",
    "Photos settings" : "Stillingar ljósmynda",
    "Back" : "Til baka",
    "Save" : "Vista",
    "Copy public link" : "Afrita opinberan tengil",
    "An error occurred" : "Villa kom upp",
    "Open the full size \"{name}\" image" : "Opna myndina \"{name}\" í fullri stærð",
    "Open the \"{name}\" sub-directory" : "Opna \"{name}\" undirmöppuna",
    "Back to {folder}" : "Til baka í {folder}",
    "Share this folder" : "Deila þessari möppu",
    "_{years} year ago_::_{years} years ago_" : ["Fyrir {years} ári","Fyrir {years} árum"],
    "Enable squared photos view" : "Virkja sýn með ferköntuðum myndum",
    "View" : "Skoða",
    "Favorite" : "Eftirlæti",
    "Remove from favorites" : "Fjarlægja úr eftirlætum",
    "This folder does not exist" : "Þessi mappa er ekki til",
    "No photos in here" : "Engar myndir hér",
    "Shared albums" : "Sameiginleg albúm",
    "No tags yet" : "Engin merki ennþá",
    "Photos with tags will show up here" : "Ljósmyndir með merkjum munu birtast hér",
    "Add" : "Bæta við",
    "Delete selection" : "Eyða vali",
    "Tagged photos" : "Merktar ljósmyndir",
    "Your photos" : "Ljósmyndirnar þínar",
    "Your videos" : "Myndskeiðin þín",
    "Your folders" : "Möppurnar þínar",
    "Settings" : "Stillingar"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
